@@ -6,8 +6,8 @@ from lxml import etree
 
 def safe_xpath(n, xpath, default=None):
     try:
-        return n.xpath(xpath)[0].text
-    except RuntimeError:
+        return trim_whitespace(n.xpath(xpath)[0].text)
+    except (RuntimeError, IndexError):
         return default
 
 
@@ -22,6 +22,27 @@ def trim_whitespace(s: str):
         return s.translate(str.maketrans({chr(13): '', chr(10): '', chr(9): ''}))
 
 
+def get_comment(tr) -> str:
+    textarea = tr.xpath("td[6]/textarea")
+    if len(textarea) == 0:
+        return trim_whitespace(tr.xpath("td[6]")[0].text)
+    else:
+        return trim_whitespace(textarea[0].text)
+
+
+def get_duration(tr) -> float:
+    select = tr.xpath("td[8]/select")
+
+    if len(select) == 0:
+        hours = safe_xpath(tr, "td[8]").split(":")[0]
+        minutes = safe_xpath(tr, "td[8]").split(":")[1]
+    else:
+        hours = safe_xpath(select[0], "option[@selected]", "0.0")
+        minutes = safe_xpath(select[1], "option[@selected]", "0.0")
+
+    return (float(hours) * 60 + float(minutes)) / 60.0
+
+
 def get_order_by_number(orders: Sequence, number: str):
     order = orders.filter(lambda o: o["number"] == number).head_option()
     if order is None:
@@ -232,7 +253,6 @@ class Connection(object):
                         "number": str(n.xpath("td[3]/following::text()[4]")[0]).translate(no_whitespace()),
                         "short": str(n.xpath("td[4]/following::text()[4]")[0]).translate(no_whitespace()),
                     },
-                    "comment": trim_whitespace(n.xpath("td[6]/textarea")[0].text),
-                    "duration": (float(safe_xpath(n, "td[8]/select[1]/option[@selected]", "0.0")) * 60.0 +
-                                 float(safe_xpath(n, "td[8]/select[2]/option[@selected]", "0.0"))) / 60.0,
+                    "comment": get_comment(n),
+                    "duration": get_duration(n)
                 })
